/**
 * An implementation of the native Map, but with deep-equality key comparison
 * API compatible with native Map, with exception of constructor
 * IN addition, a static Dict.from() function allows for additional conversions including objects and Maps
 * Note: Unlike Map, order of insertion is not retained for iteration methods
 *
 * @public
 * @category Structures
 */
export declare class HashMap<K, V> implements Iterable<[K, V]> {
    /**
     * A function constructor that handles an EntriesArray, Object, or native Map
     */
    static from<K, V>(): HashMap<K, V>;
    static from<V>(object: Record<string, V>): HashMap<string, V>;
    static from<K, V>(map: Map<K, V>): HashMap<string, V>;
    static from<K, V>(entries: Iterable<readonly [K, V]>): HashMap<string, V>;
    static groupBy<K, V>(items: Iterable<V>, keySelector: (item: V, index: number) => K): HashMap<K, V[]>;
    private root;
    private sizeInternal;
    constructor();
    constructor(iterable: Iterable<readonly [K, V]> | null);
    clear(): void;
    delete(key: K): boolean;
    entries(): IteratorObject<[K, V], undefined, unknown>;
    forEach(fn: (val: V, key: K) => void): void;
    get(key: K): V | undefined;
    has(key: K): boolean;
    keys(): IteratorObject<K, undefined, unknown>;
    set(key: K, val: V): HashMap<K, V>;
    values(): IteratorObject<V, undefined, unknown>;
    get size(): number;
    [Symbol.iterator](): IteratorObject<[K, V], undefined, unknown>;
    hashCode(): number;
    clone(): HashMap<K, V>;
    equals(other: HashMap<K, V>): boolean;
    map<U>(callbackFn: (val: V, key: K) => U): HashMap<K, U>;
    filter<S extends V>(predicate: (value: V, key: K) => value is S): HashMap<K, S>;
    filter(predicate: (value: V, key: K) => boolean): HashMap<K, V>;
    find<S extends V>(predicate: (value: V, key: K) => value is S): [K, S] | undefined;
    find(predicate: (value: V, key: K) => boolean): [K, V] | undefined;
    reduce(callbackFn: (accumulator: V, value: V, key: K) => V): V;
    reduce<U>(callbackFn: (accumulator: U, value: V, key: K) => U, initialValue: U): U;
    some(predicate: (value: V, key: K) => boolean): boolean;
    every(predicate: (value: V, key: K) => boolean): boolean;
}
